integrating rearrange-idsDoc.awk
diff --git a/klk2eureco.sh b/klk2eureco.sh
index 2e0d908..f293edc 100755
--- a/klk2eureco.sh
+++ b/klk2eureco.sh
@@ -45,6 +45,7 @@
     # Checking Wellformedness of the XML and generating TEI
     # for s in $XML/*/
     for s in $XML/Suomen_Kuvalehti/
+    # for s in $XML/Lansi-Savo/
     # for s in $XML/Helsingin_Sanomat/
     # for s in $XML/Aamulehti/ $XML/Etela-Suomen_Sanomat/ $XML/Hameen_Sanomat/ $XML/Helsingin_Sanomat/ $XML/Ilkka-Pohjalainen/ $XML/Ilta-Sanomat/ $XML/Kaleva/ $XML/Keskipohjanmaa/ $XML/Satakunnan_Kansa/ $XML/Savon_Sanomat/ $XML/Turun_Sanomat/
     do # ( # threading	
@@ -64,8 +65,10 @@
 	t0="$TEI/$SOURCE/$BASENAME.tei.0.xml"
 	
 	echo "  generating $t using vrt2tei.pl, and prettifying..."
-	./vrt2tei.pl $x | xml_pp > $t                               # xml_pp works but takes ages; xmllint- format geht out of memory und --stream machen funktioniert nicht
-
+	./vrt2tei.pl $x |
+	    xml_pp |                           # xml_pp works but takes ages;
+	    gawk -f rearrange-idsDoc.awk > $t  # rearranging the start and end tag of idsDoc
+	                                       # xmllint- format geht out of memory und --stream machen funktioniert nicht
 	ls -l $t
 
 	echo "  validating..."